summaryrefslogtreecommitdiff
path: root/include/battle_transition.h
diff options
context:
space:
mode:
authorgolem galvanize <golemgalvanize@github.com>2018-01-16 21:53:55 -0500
committergolem galvanize <golemgalvanize@github.com>2018-01-16 21:53:55 -0500
commitc06bb601837c810ec71b05c0887118269613855d (patch)
tree8ea80e699262df68bf854011e037e03b6f7542f5 /include/battle_transition.h
parent35f88987254544aa77ec3fb1906e4b545b5b5f2d (diff)
parent23f45bd2b6790df259caa180d46706cbdd54f86f (diff)
Merge branch 'master' of https://github.com/pret/pokeemerald into dump_slot_machine.s
Diffstat (limited to 'include/battle_transition.h')
-rw-r--r--include/battle_transition.h32
1 files changed, 24 insertions, 8 deletions
diff --git a/include/battle_transition.h b/include/battle_transition.h
index 84b5e37ec..0d6ef3c83 100644
--- a/include/battle_transition.h
+++ b/include/battle_transition.h
@@ -1,12 +1,27 @@
#ifndef GUARD_BATTLE_TRANSITION_H
#define GUARD_BATTLE_TRANSITION_H
-void sub_8149DFC(u8 a1);
-void BattleTransition_StartOnField(u8 transitionID);
-void BattleTransition_Start(u8 transitionID);
+void TestBattleTransition(u8 transitionId);
+void BattleTransition_StartOnField(u8 transitionId);
+void BattleTransition_Start(u8 transitionId);
bool8 IsBattleTransitionDone(void);
+bool8 FldEff_Pokeball(void);
+void TransitionPhase1_Task_RunFuncs(u8 taskId);
+void sub_8149F58(u16 **a0, u16 **a1);
-// credits for the names go to Dyskinesia and Tetrable
+extern const struct SpritePalette gFieldEffectObjectPaletteInfo10;
+
+enum // TRANSITION_MUGSHOT
+{
+ MUGSHOT_SYDNEY,
+ MUGSHOT_PHOEBE,
+ MUGSHOT_GLACIA,
+ MUGSHOT_DRAKE,
+ MUGSHOT_CHAMPION,
+ MUGSHOTS_COUNT
+};
+
+// credits for the names go to Dyskinesia, Tetrable and Farore
// names are naturally subject to change
#define B_TRANSITION_BLUR 0
@@ -35,10 +50,10 @@ bool8 IsBattleTransitionDone(void);
#define B_TRANSITION_KYOGRE 22
#define B_TRANSITION_GROUDON 23
#define B_TRANSITION_RAYQUAZA 24
-#define B_TRANSITION_25 25
-#define B_TRANSITION_26 26
-#define B_TRANSITION_27 27
-#define B_TRANSITION_28 28
+#define B_TRANSITION_SHRED_SPLIT 25
+#define B_TRANSITION_BLACKHOLE1 26
+#define B_TRANSITION_BLACKHOLE2 27
+#define B_TRANSITION_RECTANGULAR_SPIRAL 28
#define B_TRANSITION_29 29
#define B_TRANSITION_30 30
#define B_TRANSITION_31 31
@@ -52,5 +67,6 @@ bool8 IsBattleTransitionDone(void);
#define B_TRANSITION_39 39
#define B_TRANSITION_40 40
#define B_TRANSITION_41 41
+#define B_TRANSITION_COUNT 42
#endif // GUARD_BATTLE_TRANSITION_H